@@ -114,7 +114,7 @@ DisplayNameEditWidget::DisplayNameEditWidget(QWidget *parent)
     , mDisplayType(FullName)
 {
     QHBoxLayout *layout = new QHBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     mView = new KComboBox(this);
     mView->addItems(QStringList() << QString() << QString() << QString()
@@ -244,12 +244,7 @@ void DisplayNameEditWidget::updateView()
     mView->setItemText(5, mContact.formattedName());
 
     // delay the state change here, since we might have been called from mView via a signal
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     QMetaObject::invokeMethod(this,  [this]() { setComboBoxEditable(mDisplayType == CustomName); }, Qt::QueuedConnection);
-#else
-    QMetaObject::invokeMethod(this, "setComboBoxEditable", Qt::QueuedConnection, Q_ARG(bool, mDisplayType == CustomName));
-#endif
-
 
     mView->setCurrentIndex((int)mDisplayType);
 }
