@@ -2,7 +2,7 @@
     This file is part of Contact Editor.
 
     Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016-2018 Laurent Montel <laurent.montel@kdab.com>
+    Copyright (C) 2016-2019 Laurent Montel <laurent.montel@kdab.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -33,7 +33,7 @@ MailWidget::MailWidget(QWidget *parent)
 {
     QHBoxLayout *layout = new QHBoxLayout(this);
     layout->setSpacing(0);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     mMailEdit = new PreferredLineEditWidget(this);
     mMailEdit->setTrapReturnKey(true);
@@ -44,6 +44,7 @@ MailWidget::MailWidget(QWidget *parent)
 
     mMailType = new ContactEditor::ContactSelectTypeCombobox(this);
     mMailType->setObjectName(QStringLiteral("mailtype"));
+    mMailType->initialize();
     layout->addWidget(mMailType);
 
     mAddButton = new QToolButton(this);
@@ -119,7 +120,7 @@ KContacts::Email MailWidget::email()
     }
     if (mMailEdit->preferred()) {
         if (!value.contains(QLatin1String("PREF"))) {
-            value.append(QLatin1String("PREF"));
+            value.append(QStringLiteral("PREF"));
         }
     } else {
         value.removeAll(QStringLiteral("PREF"));
