@@ -34,7 +34,7 @@
 DateView::DateView(QWidget *parent)
     : QLineEdit(parent)
 {
-    setPlaceholderText(i18n("Click to Add Date"));
+    setPlaceholderText(i18n("Click to add date"));
     setReadOnly(true);
 }
 
@@ -60,7 +60,7 @@ DateEditWidget::DateEditWidget(Type type, QWidget *parent)
     , mReadOnly(false)
 {
     QHBoxLayout *layout = new QHBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     mView = new DateView;
     layout->addWidget(mView);
